@@ -12,14 +12,19 @@ class HTTPResponse:
         self._response = response
         self._body_buffer = body_buffer
         self._buffer_pointer = 0
-        self.expose_headers = self._response.headers.get('Access-Control-Expose-Headers')
+        self.expose_headers = self._response.headers.get(
+            "Access-Control-Expose-Headers"
+        )
 
     def __getitem__(self, key):
         return self._response.headers.get(key)
 
     def get(self, key, default=None):
         if "Content-Encoding" == key:
-            if 'Content-Encoding' not in self.expose_headers and 'content-encoding' not in self.expose_headers:
+            if self.expose_headers is None or (
+                "Content-Encoding" not in self.expose_headers
+                and "content-encoding" not in self.expose_headers
+            ):
                 return None
         return self._response.headers.get(key) or default
 
